@@ -25,7 +25,7 @@
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
- Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 */
 
@@ -81,7 +81,7 @@
 #include "searchbar.h"
 #include "arkviewer.h"
 
-static void viewInExternalViewer( ArkWidget* parent, const QString& filename )
+static void viewInExternalViewer( ArkWidget* parent, const KURL& filename )
 {
     QString mimetype = KMimeType::findByURL( filename )->name();
     bool view = true;
@@ -207,6 +207,8 @@ ArkWidget::busy( const QString & text )
     if ( m_bBusy )
         return;
 
+    m_fileListView->setEnabled( false );
+
     QApplication::setOverrideCursor( waitCursor );
     m_bBusy = true;
 }
@@ -237,6 +239,8 @@ ArkWidget::ready()
     if ( !m_bBusy )
         return;
 
+    m_fileListView->setEnabled( true );
+
     QApplication::restoreOverrideCursor();
     emit setReady();
     m_bBusyHold = false;
@@ -489,13 +493,6 @@ ArkWidget::extractToSlotOpenDone( bool success )
     bool keepGoing = true;
     if ( !ArkSettings::extractOverwrite() && !alreadyExisting.isEmpty() )
     {
-       if ( alreadyExisting.count() == m_nNumFiles )
-        {
-            KMessageBox::error( this, i18n( "None of the files in the archive have been\n"
-                                            "extracted since all of them already exist.") );
-            emit request_file_quit();
-            return;
-        }
         keepGoing = ( KMessageBox::Continue == KMessageBox::warningContinueCancelList( this,
                     i18n( "The following files will not be extracted\nbecause they "
                           "already exist:" ), alreadyExisting ) );
@@ -851,10 +848,10 @@ ArkWidget::extractOnlyOpenDone()
 }
 
 void
-ArkWidget::slotExtractDone()
+ArkWidget::slotExtractDone(bool success)
 {
     disconnect( arch, SIGNAL( sigExtract( bool ) ),
-                this, SLOT( slotExtractDone() ) );
+                this, SLOT( slotExtractDone(bool) ) );
     ready();
 
     if(m_extractList != 0)
@@ -876,6 +873,11 @@ ArkWidget::slotExtractDone()
         emit request_file_quit();
     }
 
+    if ( success && ArkSettings::openDestinationFolder() )
+    {
+            KRun::runURL( m_extractURL, "inode/directory" );
+    }
+
     kdDebug(1601) << "-ArkWidget::slotExtractDone" << endl;
 }
 
@@ -1242,11 +1244,13 @@ ArkWidget::action_delete()
     QStringList list = m_fileListView->selectedFilenames();
 
     // ask for confirmation
-    if ( !KMessageBox::warningContinueCancel( this,
+    if ( KMessageBox::warningContinueCancelList( this,
                                               i18n( "Do you really want to delete the selected items?" ),
+                                              list,
                                               QString::null,
-                                              KStdGuiItem::del() )
-         == KMessageBox::Continue)
+                                              KStdGuiItem::del(),
+                                              "confirmDelete" )
+         != KMessageBox::Continue)
     {
         return;
     }
@@ -1294,41 +1298,43 @@ void
 ArkWidget::slotOpenWith()
 {
     connect( arch, SIGNAL( sigExtract( bool ) ), this,
-            SLOT( openWithSlotExtractDone() ) );
+            SLOT( openWithSlotExtractDone( bool ) ) );
 
     showCurrentFile();
 }
 
 void
-ArkWidget::openWithSlotExtractDone()
+ArkWidget::openWithSlotExtractDone( bool success )
 {
     disconnect( arch, SIGNAL( sigExtract( bool ) ), this,
-            SLOT( openWithSlotExtractDone() ) );
+            SLOT( openWithSlotExtractDone( bool ) ) );
 
-    KURL::List list;
-    KURL url = m_strFileToView;
-    list.append(url);
-    KOpenWithDlg l( list, i18n("Open with:"), QString::null, (QWidget*)0L);
-    if ( l.exec() )
+    if ( success )
     {
-        KService::Ptr service = l.service();
-        if ( !!service )
-        {
-            KRun::run( *service, list );
-        }
-        else
-        {
-            QString exec = l.text();
-            exec += " %f";
-            KRun::run( exec, list );
-        }
+      KURL::List list;
+      list.append(m_viewURL);
+      KOpenWithDlg l( list, i18n("Open with:"), QString::null, (QWidget*)0L);
+      if ( l.exec() )
+      {
+          KService::Ptr service = l.service();
+          if ( !!service )
+          {
+              KRun::run( *service, list );
+          }
+          else
+          {
+              QString exec = l.text();
+              exec += " %f";
+              KRun::run( exec, list );
+          }
+      }
     }
+
     if( m_fileListView )
     {
         m_fileListView->setUpdatesEnabled(true);
         fixEnables();
     }
-
 }
 
 
@@ -1343,9 +1349,8 @@ ArkWidget::prepareViewFiles( const QStringList & fileList )
         it != fileList.end(); ++it)
         QFile::remove(destTmpDirectory + *it);
 
-    QStringList * list = new QStringList( fileList );
-    arch->unarchFile( list, destTmpDirectory, true);
-    delete list;
+    m_viewList = new QStringList( fileList );
+    arch->unarchFile( m_viewList, destTmpDirectory, true);
 }
 
 bool
@@ -1366,17 +1371,11 @@ ArkWidget::reportExtractFailures( const QString & _dest, QStringList *_list )
 
     // now report on the contents
     holdBusy();
-    if (numFilesToReport == 1)
+    if (numFilesToReport != 0)
     {
-        kdDebug(1601) << "One to report" << endl;
-        strFilename = filesExisting.first();
-        QString message = i18n("%1 will not be extracted because it will overwrite an existing file.\nGo back to the Extraction Dialog?").arg(strFilename);
-        redoExtraction = (KMessageBox::questionYesNo(this, message) == KMessageBox::Yes);
-    }
-    else if (numFilesToReport != 0)
-    {
-        QString message = i18n("Some files will not be extracted, because they would overwrite existing files.\nWould you like to go back to the extraction dialog?\n\nThe following files will not be extracted if you choose to continue:");
-        redoExtraction = (KMessageBox::questionYesNoList(this, message, filesExisting) == KMessageBox::Yes);
+        redoExtraction =  ( KMessageBox::Cancel == KMessageBox::warningContinueCancelList( this,
+                    i18n( "The following files will not be extracted\nbecause they "
+                          "already exist:" ), filesExisting ) );
     }
     resumeBusy();
     return redoExtraction;
@@ -1406,7 +1405,9 @@ ArkWidget::existingFiles( const QString & _dest, QStringList & _list )
     {
         strFilename = *it;
         QString strFullName = strDestDir + strFilename;
-        if ( QFile::exists( strFullName ) )
+
+        // if the filename ends with an "/", it means it is a directory
+        if ( QFile::exists( strFullName ) && !strFilename.endsWith("/") )
         {
             existingFiles.append( strFilename );
         }
@@ -1437,7 +1438,8 @@ ArkWidget::action_extract()
                          : QString();
 
     // Should the extraction dialog show an option for extracting only selected files?
-    bool enableSelected = ( m_nNumSelectedFiles > 0 );
+   bool enableSelected = ( m_nNumSelectedFiles > 0 ) &&
+        ( m_fileListView->totalFiles() > 1);
 
     QString base = ArkSettings::extractionHistory().isEmpty()?
                        QString() : ArkSettings::extractionHistory().first();
@@ -1509,7 +1511,7 @@ ArkWidget::action_extract()
                 {
                     disableAll();
                     busy( i18n( "Extracting..." ) );
-                    connect( arch, SIGNAL( sigExtract( bool ) ), this, SLOT( slotExtractDone() ) );
+                    connect( arch, SIGNAL( sigExtract( bool ) ), this, SLOT( slotExtractDone(bool) ) );
                     arch->unarchFile(0, extractDir);
                 }
             }
@@ -1537,15 +1539,11 @@ ArkWidget::action_extract()
                         disableAll();
                         busy( i18n( "Extracting..." ) );
                         connect( arch, SIGNAL( sigExtract( bool ) ),
-                                 this, SLOT( slotExtractDone() ) );
+                                 this, SLOT( slotExtractDone(bool) ) );
                         arch->unarchFile(m_extractList, extractDir); // extract selected files
                     }
                 }
         }
-        if ( dlg->viewFolderAfterExtraction() )
-        {
-            KRun::runURL( dlg->extractionDirectory(), "inode/directory" );
-        }
 
         delete dlg;
     }
@@ -1606,7 +1604,7 @@ ArkWidget::editStart()
     if ( l.exec() )
     {
         KProcess *kp = new KProcess;
-        m_strFileToView = m_strFileToView.right(m_strFileToView.length() - 5 );
+
         *kp << l.text() << m_strFileToView;
         connect( kp, SIGNAL(processExited(KProcess *)),
                 this, SLOT(slotEditFinished(KProcess *)) );
@@ -1687,23 +1685,26 @@ ArkWidget::viewSlotExtractDone( bool success )
         {
             ArkViewer * viewer = new ArkViewer( this, "viewer" );
 
-            if ( !viewer->view( m_strFileToView ) )
+            if ( !viewer->view( m_viewURL ) )
             {
                 QString text = i18n( "The internal viewer is not able to display this file. Would you like to view it using an external program?" );
                 view = ( KMessageBox::warningYesNo( this, text, QString::null, i18n("View Externally"), i18n("Do Not View") ) == KMessageBox::Yes );
 
                 if ( view )
-                    viewInExternalViewer( this, m_strFileToView );
+                    viewInExternalViewer( this, m_viewURL );
             }
         }
         else
         {
-            viewInExternalViewer( this, m_strFileToView );
+            viewInExternalViewer( this, m_viewURL );
         }
     }
 
     disconnect( arch, SIGNAL( sigExtract( bool ) ), this,
                 SLOT( viewSlotExtractDone( bool ) ) );
+
+    delete m_viewList;
+
     // avoid race condition, don't do updates if application is exiting
     if( m_fileListView )
     {
@@ -1722,17 +1723,21 @@ ArkWidget::showCurrentFile()
 
     QString name = m_fileListView->currentItem()->fileName();
 
-    QString fullname;
-    fullname = "file:";
-    fullname += tmpDir();
+    QString fullname = tmpDir();
     fullname += name;
 
-    kdDebug(1601) << "File to be viewed: " << fullname << endl;
+    if(fullname.contains("../"))
+        fullname.remove("../");
+
+    //Convert the QString filename to KURL to escape the bad characters
+    m_viewURL.setPath(fullname);
+
+    m_strFileToView = fullname;
+    kdDebug(1601) << "File to be extracted: " << m_viewURL << endl;
 
     QStringList extractList;
     extractList.append(name);
 
-    m_strFileToView = fullname;
     if (ArkUtils::diskHasSpace( tmpDir(), m_fileListView->currentItem()->fileSize() ) )
     {
         disableAll();
@@ -2029,9 +2034,9 @@ Arch * ArkWidget::getNewArchive( const QString & _fileName, const QString& _mime
         return NULL;
     }
 
-    if (!newArch->utilityIsAvailable())
+    if (!newArch->archUtilityIsAvailable())
     {
-        KMessageBox::error(this, i18n("The utility %1 is not in your PATH.\nPlease install it or contact your system administrator.").arg(newArch->getUtility()));
+        KMessageBox::error(this, i18n("The utility %1 is not in your PATH.\nPlease install it or contact your system administrator.").arg(newArch->getArchUtility()));
         return NULL;
     }
 
@@ -2141,9 +2146,9 @@ ArkWidget::openArchive( const QString & _filename )
         return;
     }
 
-    if (!newArch->utilityIsAvailable())
+    if (!newArch->unarchUtilityIsAvailable())
     {
-        KMessageBox::error(this, i18n("The utility %1 is not in your PATH.\nPlease install it or contact your system administrator.").arg(newArch->getUtility()));
+        KMessageBox::error(this, i18n("The utility %1 is not in your PATH.\nPlease install it or contact your system administrator.").arg(newArch->getUnarchUtility()));
         return;
     }
 
