@@ -105,7 +105,7 @@ Monitor::DisplayType AsusMonitor::poll()
 		m_progress = ROUND(value * 100);
 	}
 
-	if (last_asus_state.lcd != asus_state.lcd)
+	/*if (last_asus_state.lcd != asus_state.lcd)
 	{
 		if (asus_state.lcd == 0)
 		{
@@ -115,7 +115,7 @@ Monitor::DisplayType AsusMonitor::poll()
 		{
 			_interface->displayText(i18n("Display changed: LCD on"));
 		}
-	}
+	}*/
 
 	if (last_asus_state.display != asus_state.display)
 	{
@@ -173,7 +173,7 @@ bool AsusMonitor::readProc(asus_state_struct* asus_state)
 		asus_state->display = value;
 #else
 	asus_state->brightness = readProcEntry(QString("brn"));
-	asus_state->lcd = readProcEntry(QString("lcd"));
+	//asus_state->lcd = readProcEntry(QString("lcd"));
 	//disabled because it does not yet work on my S5200N (asus_acpi bug)
 	//asus_state->display = readProcEntry(QString("disp"));
 	//FIXME
