@@ -14,8 +14,8 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 
@@ -1104,7 +1104,17 @@ void KWalletEditor::exportXML() {
 	KURL url = KFileDialog::getSaveURL(QString::null, "*.xml", this);
 
 	if (!url.isEmpty()) {
-		KIO::NetAccess::file_copy(tf.name(), url, 0600, false, false, this);
+		bool ok = true;
+		if (KIO::NetAccess::exists(url, false, this)) {
+			int rc = KMessageBox::warningContinueCancel(this, i18n("The file '%1' already exists. Would you like to overwrite this file?").arg(url.prettyURL()), i18n("Overwrite"));
+			if (rc == KMessageBox::Cancel) {
+				ok = false;
+			}
+		}
+		if (ok) {
+			KURL tfURL; tfURL.setPath(tf.name());
+			KIO::NetAccess::file_copy(tfURL, url, 0600, true, false, this);
+		}
 	}
 }
 
@@ -1119,10 +1129,11 @@ void KWalletEditor::saveAs() {
 	if (!url.isEmpty()) {
 		// Sync() kwalletd
 		if (_nonLocal) {
-			KIO::NetAccess::file_copy(_walletName, url, 0600, false, false, this);
+			KIO::NetAccess::file_copy(KURL(_walletName), url, 0600, false, false, this);
 		} else {
 			QString path = KGlobal::dirs()->saveLocation("kwallet") + "/" + _walletName + ".kwl";
-			KIO::NetAccess::file_copy(path, url, 0600, false, false, this);
+			KURL destURL; destURL.setPath(path);
+			KIO::NetAccess::file_copy(destURL, url, 0600, false, false, this);
 		}
 	}
 }
